## Berkeley Autolab Perception Module

[![Build Status](https://travis-ci.org/BerkeleyAutomation/perception.svg?branch=master)](https://travis-ci.org/BerkeleyAutomation/perception)

This package provides a wide variety of useful tools for perception tasks.
It directly depends on the [Berkeley Autolab Core
module](https://www.github.com/BerkeleyAutomation/autolab_core), so be sure to install
that first.
View the install guide and API documentation for the perception module
[here](https://BerkeleyAutomation.github.io/perception).
